==> xl-security-tests-23.3.3-sources.jar: com/xebialabs/xlplatform/security/RoleService_GlobalTest.scala <==
package com.xebialabs.xlplatform.security

import com.xebialabs.deployit.engine.api.dto.{Ordering, Paging}
import com.xebialabs.deployit.security.{Role, RoleService}
import com.xebialabs.xlplatform.test.UnitTestBase

import scala.jdk.CollectionConverters._

trait RoleService_GlobalTest extends UnitTestBase {
  implicit val roleService: RoleService

  var roleAssignments: Seq[Role] = Seq[Role]()
  var developer: Role = _
  var deployer: Role = _
  var administrator: Role = _

  var readRoleAssignmentsPaginationImplemented = false
  var countImplemented = false

  protected def setup(): Unit = {
    developer = new Role("developer")
    deployer = new Role("deployer")
    administrator = new Role("administrator")
    developer.getPrincipals.add("john")
    deployer.getPrincipals.addAll(Seq("john", "sam").asJava)
    administrator.getPrincipals.add("kate")
    roleAssignments = Seq(developer, deployer, administrator)
  }

  protected def tearDown(): Unit = {
    roleService.writeRoleAssignments(Seq[Role]().asJava)
  }

  describe("Role Service with global roles") {
    it("should not fail on no roles read", IgnoreTestOnDeployTag) {
      val rolePrincipalsMap = roleService.readRoleAssignments().asScala

      assert(rolePrincipalsMap != null)
      assert(rolePrincipalsMap.isEmpty)
    }

    it("should read written roles", IgnoreTestOnDeployTag) {
      val roles = roleService.getRoles().asScala

      assert(roles.isEmpty)

      roleService.writeRoleAssignments(roleAssignments.asJava)

      assert(roleService.getRoles().size() == 3)
    }

    it("should read and write role assignments", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val result = roleService.readRoleAssignments().asScala

      result should contain theSameElementsAs roleAssignments
    }

    it("should overwrite existing roles with new", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      roleService.writeRoleAssignments(List[Role]().asJava)

      assert(roleService.readRoleAssignments().size() == 0)
    }

    it("should get no roles for non existing principal", IgnoreTestOnDeployTag) {
      val paging1 = new Paging(1, 1)
      val order = new Ordering("name:DESC")
      val rolesFor = roleService.getRolesFor("non-existing", null, paging1, order).asScala

      assert(rolesFor.isEmpty)
    }

    it("should get roles for existing principals", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val rolesForJohn = roleService.getRolesFor("john").asScala

      assert(rolesForJohn.contains(developer))
      assert(rolesForJohn.contains(deployer))

      val rolesForKate = roleService.getRolesFor("kate").asScala

      assert(rolesForKate.contains(administrator))
    }

    it("should get role by role name") {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val role = roleService.getRoleForRoleName("developer")

      role.getId should not be null
      role.getName shouldBe "developer"
    }

    it("should throw exception when fetching role by unknown role name") {
      roleService.writeRoleAssignments(roleAssignments.asJava)

      the[Exception] thrownBy roleService.getRoleForRoleName("unknown") should have(Symbol("message")("Could not find the role [unknown]"))
    }

    it("should get role by role id", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val role = roleService.getRoleForRoleId(developer.getId)

      role.getId shouldBe developer.getId
      role.getName shouldBe "developer"
    }

    it("should throw exception when fetching role by unknown role id", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)

      the[Exception] thrownBy roleService.getRoleForRoleId("unknown") should have(Symbol("message")("Could not find the role with id [unknown]"))
    }

    it("should assign new id to new role", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val loser: Role = new Role("loser")
      loser.getPrincipals.add("mallory")
      val otherRoleAssignments: Seq[Role] = loser +: roleAssignments.filterNot(_.equals(developer))
      roleService.writeRoleAssignments(otherRoleAssignments.asJava)
      val roles = roleService.getRoles().asScala

      assert(!roles.contains(developer))
      assert(roles.contains(loser))
      assert(roles(roles.indexOf(loser)).getId != null)
    }

    it("should assign new id to new role with minus 1 Id", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val loser: Role = new Role(null, "loser")
      loser.getPrincipals.add("mallory")
      val otherRoleAssignments: Seq[Role] = loser +: roleAssignments.filterNot(_.equals(developer))
      roleService.writeRoleAssignments(otherRoleAssignments.asJava)
      val roles = roleService.getRoles().asScala

      assert(!roles.contains(developer))
      assert(roles.contains(loser))
      assert(roles(roles.indexOf(loser)).getId != null)
    }

    it("should not merge two roles with empty role id", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val loser: Role = new Role("loser")
      loser.getPrincipals.add("mallory")
      val superman: Role = new Role("superman")
      superman.getPrincipals.add("clark")
      val otherRoleAssignments: Seq[Role] = loser +: superman +: roleAssignments

      roleService.writeRoleAssignments(otherRoleAssignments.asJava)
      val roles = roleService.readRoleAssignments().asScala

      assert(roles.contains(loser))
      assert(roles.contains(superman))
      assert(roles(roles.indexOf(loser)).getPrincipals.contains("mallory"))
      assert(!roles(roles.indexOf(loser)).getPrincipals.contains("clark"))
      assert(roles(roles.indexOf(superman)).getPrincipals.contains("clark"))
      assert(!roles(roles.indexOf(superman)).getPrincipals.contains("mallory"))
    }

    it("should be able to update a role name", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val savedAssignments = roleService.readRoleAssignments().asScala
      val devRole = savedAssignments.find(_.getId == developer.getId).head
      devRole.setName("ScalaDeveloper")

      roleService.writeRoleAssignments(savedAssignments.asJava)
      val updatedAssignments = roleService.readRoleAssignments().asScala
      val updatedDevRole = updatedAssignments.find(role => role.getName == devRole.getName && role.getId == devRole.getId).head

      assert(updatedAssignments.size == roleAssignments.size)
      assert(updatedDevRole.getPrincipals.containsAll(developer.getPrincipals))
    }

    if (readRoleAssignmentsPaginationImplemented) {
      it("should read and write role assignments with paging and ordering", IgnoreTestOnDeployTag) {
        roleService.writeRoleAssignments(roleAssignments.asJava)
        val paging1 = new Paging(1, 1)
        val order = new Ordering("name:DESC")
        val result = roleService.readRoleAssignments("de", paging1, order).asScala

        assert(result.size == 1)
        assert(result.head.getName === "deployer")

        result should contain theSameElementsAs roleAssignments
      }
    }

    it("should be able to paginate roles", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val paging1 = new Paging(1, 2)
      val order = new Ordering("ASC")
      val rolesForJohn = roleService.getRolesFor("john", null, paging1, order).asScala

      assert(rolesForJohn.size.equals(2))
      assert(rolesForJohn.contains(developer))
    }

    it("should sort roles by role name", IgnoreTestOnDeployTag) {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val paging1 = new Paging(1, 2)
      val order = new Ordering("DESC")
      val rolesForJohn = roleService.getRolesFor("john", "d", paging1, order).asScala

      assert(rolesForJohn.size.equals(2))
      assert(rolesForJohn.contains(deployer))
    }

    if (countImplemented) {
      it("should count roles by id", IgnoreTestOnDeployTag) {
        roleService.writeRoleAssignments(roleAssignments.asJava)
        assert(roleService.countRoles(-1, "") == 3)
        assert(roleService.countRoles(-1, "de") == 2)
      }

      it("should count roles by alias", IgnoreTestOnDeployTag) {
        roleService.writeRoleAssignments(roleAssignments.asJava)
        assert(roleService.countRoles("global", "") == 3)
        assert(roleService.countRoles("global", "de") == 2)
      }
    }
  }
}

==> xl-security-tests-2018.3.1-sources.jar: com/xebialabs/xlplatform/security/RoleService_GlobalTest.scala <==
package com.xebialabs.xlplatform.security

import com.xebialabs.deployit.security.{Role, RoleService}
import com.xebialabs.xlplatform.test.UnitTestBase

import scala.collection.JavaConverters._

trait RoleService_GlobalTest extends UnitTestBase {
  implicit val roleService: RoleService

  var roleAssignments: Seq[Role] = Seq[Role]()
  var developer: Role = _
  var deployer: Role = _
  var administrator: Role = _

  protected def setup(): Unit = {
    developer = new Role("developer")
    deployer = new Role("deployer")
    administrator = new Role("administrator")
    developer.getPrincipals.add("john")
    deployer.getPrincipals.addAll(Seq("john", "sam").asJava)
    administrator.getPrincipals.add("kate")
    roleAssignments = Seq(developer, deployer, administrator)
  }

  protected def tearDown(): Unit = {
    roleService.writeRoleAssignments(Seq[Role]().asJava)
  }

  describe("Role Service with global roles") {
    it("should not fail on no roles read") {
      val rolePrincipalsMap = roleService.readRoleAssignments.asScala

      assert(rolePrincipalsMap != null)
      assert(rolePrincipalsMap.isEmpty)
    }

    it("should read written roles") {
      val roles = roleService.getRoles.asScala

      assert(roles.isEmpty)

      roleService.writeRoleAssignments(roleAssignments.asJava)

      assert(roleService.getRoles.size() == 3)
    }

    it("should read and write role assignments") {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val result = roleService.readRoleAssignments.asScala

      result should contain theSameElementsAs roleAssignments
    }

    it("should overwrite existing roles with new") {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      roleService.writeRoleAssignments(List[Role]().asJava)

      assert(roleService.readRoleAssignments.size() == 0)
    }

    it("should get no roles for non existing principal") {
      val rolesFor = roleService.getRolesFor("non-existing").asScala

      assert(rolesFor.isEmpty)
    }

    it("should get roles for existing principals") {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val rolesForJohn = roleService.getRolesFor("john").asScala

      assert(rolesForJohn.contains(developer))
      assert(rolesForJohn.contains(deployer))

      val rolesForKate = roleService.getRolesFor("kate").asScala

      assert(rolesForKate.contains(administrator))
    }

    it("should get role by role name") {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val role = roleService.getRoleForRoleName("developer")

      role.getId should not be null
      role.getName shouldBe "developer"
    }

    it("should throw exception when fetching role by unknown role name") {
      roleService.writeRoleAssignments(roleAssignments.asJava)

      the[Exception] thrownBy roleService.getRoleForRoleName("unknown") should have('message ("Could not find the role [unknown]"))
    }

    it("should assign new id to new role") {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val loser: Role = new Role("loser")
      loser.getPrincipals.add("mallory")
      val otherRoleAssignments: Seq[Role] = loser +: roleAssignments.filterNot(_.equals(developer))
      roleService.writeRoleAssignments(otherRoleAssignments.asJava)
      val roles = roleService.getRoles.asScala

      assert(!roles.contains(developer))
      assert(roles.contains(loser))
      assert(roles(roles.indexOf(loser)).getId != null)
    }

    it("should assign new id to new role with minus 1 Id") {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val loser: Role = new Role(null, "loser")
      loser.getPrincipals.add("mallory")
      val otherRoleAssignments: Seq[Role] = loser +: roleAssignments.filterNot(_.equals(developer))
      roleService.writeRoleAssignments(otherRoleAssignments.asJava)
      val roles = roleService.getRoles.asScala

      assert(!roles.contains(developer))
      assert(roles.contains(loser))
      assert(roles(roles.indexOf(loser)).getId != null)
    }

    it("should not merge two roles with empty role id") {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val loser: Role = new Role("loser")
      loser.getPrincipals.add("mallory")
      val superman: Role = new Role("superman")
      superman.getPrincipals.add("clark")
      val otherRoleAssignments: Seq[Role] = loser +: superman +: roleAssignments

      roleService.writeRoleAssignments(otherRoleAssignments.asJava)
      val roles = roleService.readRoleAssignments.asScala

      assert(roles.contains(loser))
      assert(roles.contains(superman))
      assert(roles(roles.indexOf(loser)).getPrincipals.contains("mallory"))
      assert(!roles(roles.indexOf(loser)).getPrincipals.contains("clark"))
      assert(roles(roles.indexOf(superman)).getPrincipals.contains("clark"))
      assert(!roles(roles.indexOf(superman)).getPrincipals.contains("mallory"))
    }

    it("should be able to update a role name") {
      roleService.writeRoleAssignments(roleAssignments.asJava)
      val savedAssignments = roleService.readRoleAssignments.asScala
      val devRole = savedAssignments.find(_.getId == developer.getId).head
      devRole.setName("ScalaDeveloper")

      roleService.writeRoleAssignments(savedAssignments.asJava)
      val updatedAssignments = roleService.readRoleAssignments.asScala
      val updatedDevRole = updatedAssignments.find(role => role.getName == devRole.getName && role.getId == devRole.getId).head

      assert(updatedAssignments.size == roleAssignments.size)
      assert(updatedDevRole.getPrincipals.containsAll(developer.getPrincipals))
    }
  }
}
